package components

import androidx.compose.foundation.layout.*
import androidx.compose.material.Button
import androidx.compose.material.ButtonDefaults
import androidx.compose.material.Surface
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.em
import data.ColorData
import data.toColorOrDefault

@Suppress("FunctionName")
@Composable
fun GameHeader(title: String, color: ColorData?, onExit: () -> Unit) {
    Row(
        modifier = Modifier.fillMaxHeight(0.2f)
            .fillMaxWidth()
    ) {
        Surface(
            color = color.toColorOrDefault(),
            modifier = Modifier.fillMaxSize(1f)
        ) {
            Column(
                verticalArrangement = Arrangement.Center,
                horizontalAlignment = Alignment.CenterHorizontally,
                modifier = Modifier.fillMaxWidth(0.9f)
                    .fillMaxHeight()
            ) {
                Text(text = title, color = Color.LightGray, fontSize = 8.em)
            }
            Column(
                verticalArrangement = Arrangement.Top,
                horizontalAlignment = Alignment.End,
                modifier = Modifier.fillMaxSize()
            ) {
                Button(onClick = onExit, colors = ButtonDefaults.buttonColors(Color.Red)) {
                    Text(text = "X", color = Color.LightGray)
                }
            }
        }
    }
}
